# Changelog

## v0.0.4 - Feb 24, 2025

**Improvement**:
-   Performance Improvements

**New Features**:
-   Added methods for prototypes transformation  

## v0.0.3 - Nov 25, 2023

**Improvement**:
-   Performance Improvements

**New Features**:

-   Introduces Mutation Validation for Robustness

## v0.0.2 - Sep 23, 2023

**Improvement**:
-   Performance Improvements

**New Features**:

-   Evaluation Reports
-   visualizations

## v0.0.1 - Sep 23, 2023

-   Initial Release